@@ -22,6 +22,7 @@ def help():
     print(" list = torancell.handgen()")
     print(" torancell.shantenquiz()")
     print(" torancell.tenhou(step)")
+    print(" torancell.furansugo()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -552,4 +553,170 @@ def tenhou(step=1000):
                     print(str(hand)+"\t\t"+str(result)+"向牌 "+str(i)+"局目")
                 else:
                     print(str(hand)+"\t"+str(result)+"向牌 "+str(i)+"局目")
-        i = i+1
\ No newline at end of file
+        i = i+1
+
+
+def furansugo():
+    francais = ["Tu peux venir ce soir? ---Avec plaisir.",
+            "Je peux ouvrir la fenetre?",
+            "Elle ne peut pas repondre a cette question.",
+            "Elle vent avoir un chien depuis longtemps.",
+            "Ils veulent descendre dans la rue.",
+            "Jensais qu'il veut sortir avev moi.",
+            "Voulez-vous quelque chose a boire? ---Non, je ne veux rien.",
+            "Chacun doit respecter les droits de l'homme.",
+            "Vous ne devez pas entrer sans frapper.",
+            "Marie arrivera demain matin.",
+            "J'aurai vingt ans l'annee prochaine.",
+            "Il deviendra footballeur professionnel.",
+            "Tu n'oublieras oas ton sac.",
+            "Elles sont riches? ---Oui, elles le sont.",
+            "Je peux entrer? ---Oui, vous le pouvez.",
+            "Tu sais qu'elle est mariee? ---Non, je ne le sais pas.",
+            "Vous venez de Lyon? ---Oui,j'en viens.",
+            "Elle a parle de ce firm? ---Oui, elle en a parle.",
+            "Tu as besoin de mon aide? ---Oui, j'en ai besoin.",
+            "Vous avez des cigarettes? ---Oui, j'en ai.",
+            "Vous voulez du cafe? ---Oui, j'en veux bien.",
+            "Tu as mange de la salade? ---Oui, j'en ai mange.",
+            "Tu as mange de la salade? ---Non,je n'en ai pas mange.",
+            "Combien de freres avez-vous? ---J'en ai deux.",
+            "Elle habite en France? ---Oui, elle y habite.",
+            "Tu as alle au Senegal? ---Non, je n'y suis pas alle.",
+            "Yvonne pense au mariage? ---Oui, elle y pense.",
+            "Quand je suis rentre, ma femme preparait le diner.",
+            "En ce temps-la, Julie travaillait pour une maison d'edition.",
+            "Dans mon enfance, j'allais a l'eglise tous les dimanches.",
+            "Francois invite Sophie. -->Sophie est invitee par Francois.",
+            "Francois a invite Sophie. -->Sophie a ete invitee par Francois.",
+            "Tout le monde aime Lena. -->Lena est aimee de tout le monde.",
+            "Toutes les filles dansant sur la scene portent le meme foulard.",
+            "Ayant faim, nous avons cherche un restaurant.",
+            "Ne parle pas en mangeant.",
+            "J'ai rencontre Julie en sortant du cafe.",
+            "J'ai rencontre Julie sortant du cafe.",
+            "En prenant le metro, vous arriverez a temps.",
+            "Tout en etant tres malade, il est alle a l'examen.",
+            ]
+            
+    japanese = ["今夜来られる？ ---喜んで",
+            "窓を開けてもいいですか？",
+            "彼女はその質問には答えられない。",
+            "彼女はずっと前から犬を飼いたがっている。",
+            "彼らはデモのために街頭に繰り出したがっている。",
+            "彼がわたしとデートしたがっているのは知っています。",
+            "なにか飲み物はいかがですか？ ---いいえ、なにも欲しくありません。",
+            "各人が人権を尊重しなくてはならない。",
+            "ノックせずに入ってはいけません。",
+            "マリーは明日の朝到着するだろう。",
+            "来年二十歳になります。",
+            "彼はプロのサッカー選手になるだろう。",
+            "バッグを忘れないようにね。",
+            "彼女らはお金持ちですか？ ---はい、そうです。",
+            "入っていいですか？ ---どうぞ、お入りください。",
+            "彼女が結婚してること知ってる？ ---いや、そのことは知らない。",
+            "リヨンから来ているのですか？ ---はい、そこから来ています。",
+            "彼女はこの映画について話しましたか？ ---はい、それについて話しました。",
+            "わたしの助けが必要なの？ ---はい、それが必要です。",
+            "煙草ありますか？ ---はい、あります。",
+            "コーヒー欲しいですか？ ---はい、欲しいです。",
+            "サラダ食べた？ ---はい、食べました。",
+            "サラダ食べた？ ---いいえ、食べていません。",
+            "姉弟は何人ですか？ ---二人です。",
+            "彼女はフランスに住んでいるのですか？ ---はい、彼女はそこに住んでいます。",
+            "セネガルに行った？ ---いや、そこには行かなかった。",
+            "イヴォンヌは結婚のことを考えていますか？ ---はい、そのことを考えています。",
+            "わたしが帰宅したとき、妻は夕食の準備をしていた。",
+            "そのころ、ジュリーは出版社で働いていた。",
+            "子供の頃、毎週日曜日に教会へ行ったものだ。",
+            "フランソワはソフィーを招待する。 -->ソフィーはフランソワに招待される。",
+            "フランソワはソフィーを招待した。 -->ソフィーはフランソワに招待された。",
+            "みんながレナを愛している。 -->レナはみんなに愛されている。",
+            "舞台で踊っているすべての少女たちが、同じスカーフをしている。",
+            "お腹がすいたので、わたしたちはレストランを探した。",
+            "食べながら話すな。",
+            "カフェから出てきたとき、ジュリーに会った。",
+            "カフェから出てきたジュリーに会った。",
+            "メトロに乗れば、定刻に着くでしょう。",
+            "とても具合が悪かったけれども、彼は試験に行った。",
+            ]
+
+    futuniti = dict(zip(francais,japanese))
+
+    def JtoF(step=len(japanese),mondaisuu=4):
+        seikaisuu = 0
+        box = rm.sample(range(len(japanese)),step)
+        for a in range(step):
+            answer = box.pop()
+            print(japanese[answer])
+            choice = []
+            choice.append(francais[answer])
+            for i in range(mondaisuu-1):
+                choice.append(francais[rm.randint(0,len(japanese)-1)])
+            rm.shuffle(choice)
+            for i in range(mondaisuu):
+                print(str(i+1)+", "+choice[i])
+            select_answer = int(input("choice answer:"))
+            if(francais[answer] == choice[select_answer-1]):
+                print("Good!")
+                seikaisuu += 1
+            else:
+                print("answer is ["+francais[answer]+"]")
+        print("あなたの得点は"+str((seikaisuu/step)*100)+"です。")
+
+
+
+    def FtoJ(step=len(francais),mondaisuu=4):
+        seikaisuu = 0
+        box = rm.sample(range(len(francais)),step)
+        for a in range(step):
+            answer = box.pop()
+            print("\n"+francais[answer])
+            choice = []
+            choice.append(japanese[answer])
+            for i in range(mondaisuu-1):
+                choice.append(japanese[rm.randint(0,len(francais)-1)])
+            rm.shuffle(choice)
+            for i in range(mondaisuu):
+                print(str(i+1)+", "+choice[i])
+            select_answer = int(input("choice answer:"))
+            if(japanese[answer] == choice[select_answer-1]):
+                print("Good!")
+                seikaisuu += 1
+            else:
+                print("answer is ["+japanese[answer]+"]")
+        print("あなたの得点は"+str((seikaisuu/step)*100)+"です。")
+
+    def nihongo():
+        box = rm.sample(range(len(francais)),len(francais))
+        for i in box:
+            print(francais[i],end="")
+            aaaaa = input()
+            print(japanese[i])
+            print()
+    def futugo():
+        box = rm.sample(range(len(francais)),len(francais))
+        for i in box:
+            print(japanese[i],end="")
+            aaaaa = input()
+            print(francais[i])
+            print()
+
+    print("～わくわくフランス語クイズ～\n[数値を入力してください]")
+    kazu = 5
+    select = int(input("1, Francais to Japanese Quiz\n2, Japanese to Francais Quiz\n3, Francais list\n4, Japanese list\n"))
+    if(select <= 2):
+        kazu = int(input("How many number of questions?:"))
+    if(kazu>40):
+        kazu = 40
+    if(select == 1):
+        FtoJ(kazu)
+    elif(select == 2):
+        JtoF(kazu)
+    elif(select == 3):
+        nihongo()
+    elif(select == 4):
+        futugo()
+    else:
+        print("Fuck you!")
+    time.sleep(5)
\ No newline at end of file
